# Config file for the MetviewBundle package
# Defines the following variables:
#
#  MetviewBundle_FEATURES       - list of enabled features
#  MetviewBundle_VERSION        - version of the package
#  MetviewBundle_GIT_SHA1       - Git revision of the package
#  MetviewBundle_GIT_SHA1_SHORT - short Git revision of the package
#


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was project-config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

### computed paths
set_and_check(MetviewBundle_CMAKE_DIR "${PACKAGE_PREFIX_DIR}/lib/cmake/MetviewBundle")
set_and_check(MetviewBundle_BASE_DIR "${PACKAGE_PREFIX_DIR}/.")
if(DEFINED ECBUILD_2_COMPAT AND ECBUILD_2_COMPAT)
  set(METVIEWBUNDLE_CMAKE_DIR ${MetviewBundle_CMAKE_DIR})
  set(METVIEWBUNDLE_BASE_DIR ${MetviewBundle_BASE_DIR})
endif()

### export version info
set(MetviewBundle_VERSION           "2025.4.0")
set(MetviewBundle_GIT_SHA1          "")
set(MetviewBundle_GIT_SHA1_SHORT    "")

if(DEFINED ECBUILD_2_COMPAT AND ECBUILD_2_COMPAT)
  set(METVIEWBUNDLE_VERSION           "2025.4.0" )
  set(METVIEWBUNDLE_GIT_SHA1          "" )
  set(METVIEWBUNDLE_GIT_SHA1_SHORT    "" )
endif()

### has this configuration been exported from a build tree?
set(MetviewBundle_IS_BUILD_DIR_EXPORT OFF)
if(DEFINED ECBUILD_2_COMPAT AND ECBUILD_2_COMPAT)
  set(METVIEWBUNDLE_IS_BUILD_DIR_EXPORT ${MetviewBundle_IS_BUILD_DIR_EXPORT})
endif()

### include the <project>-import.cmake file if there is one
if(EXISTS ${MetviewBundle_CMAKE_DIR}/metviewbundle-import.cmake)
  set(MetviewBundle_IMPORT_FILE "${MetviewBundle_CMAKE_DIR}/metviewbundle-import.cmake")
  include(${MetviewBundle_IMPORT_FILE})
endif()

### insert definitions for IMPORTED targets
if(NOT MetviewBundle_BINARY_DIR)
  find_file(MetviewBundle_TARGETS_FILE
    NAMES MetviewBundle-targets.cmake
    HINTS ${MetviewBundle_CMAKE_DIR}
    NO_DEFAULT_PATH)
  if(MetviewBundle_TARGETS_FILE)
    include(${MetviewBundle_TARGETS_FILE})
  endif()
endif()

### include the <project>-post-import.cmake file if there is one
if(EXISTS ${MetviewBundle_CMAKE_DIR}/metviewbundle-post-import.cmake)
  set(MetviewBundle_POST_IMPORT_FILE "${MetviewBundle_CMAKE_DIR}/metviewbundle-post-import.cmake")
  include(${MetviewBundle_POST_IMPORT_FILE})
endif()

### handle third-party dependencies
if(DEFINED ECBUILD_2_COMPAT AND ECBUILD_2_COMPAT)
  set(METVIEWBUNDLE_LIBRARIES         "")
  set(METVIEWBUNDLE_TPLS              "" )

  include(${CMAKE_CURRENT_LIST_FILE}.tpls OPTIONAL)
endif()

### publish this file as imported
if( DEFINED ECBUILD_2_COMPAT AND ECBUILD_2_COMPAT )
  set(MetviewBundle_IMPORT_FILE ${CMAKE_CURRENT_LIST_FILE})
  mark_as_advanced(MetviewBundle_IMPORT_FILE)
  set(METVIEWBUNDLE_IMPORT_FILE ${CMAKE_CURRENT_LIST_FILE})
  mark_as_advanced(METVIEWBUNDLE_IMPORT_FILE)
endif()

### export features and check requirements
set(MetviewBundle_FEATURES "TESTS;PKGCONFIG;ECKIT_SQL;EIGEN;BZIP2;LZ4;AEC;XXHASH;ECKIT_CODEC;LAPACK;CURL;UNICODE;AIO;WARNINGS;ATLAS_GRID;ATLAS_FIELD;ATLAS_FUNCTIONSPACE;ATLAS_INTERPOLATION;ATLAS_TRANS;ATLAS_NUMERICS;FFTW;ATLAS_RUN;NETCDF;PNG;ATLAS;PPROC_MIR;RPC;CAIRO;METVIEW;PKGCONFIG")
if(DEFINED ECBUILD_2_COMPAT AND ECBUILD_2_COMPAT)
  set(METVIEWBUNDLE_FEATURES ${MetviewBundle_FEATURES})
endif()
foreach(_f ${MetviewBundle_FEATURES})
  set(MetviewBundle_${_f}_FOUND 1)
  set(MetviewBundle_HAVE_${_f} 1)
  if(DEFINED ECBUILD_2_COMPAT AND ECBUILD_2_COMPAT)
    set(METVIEWBUNDLE_HAVE_${_f} 1)
  endif()
endforeach()
check_required_components(MetviewBundle)
